"""
```{warning}
Do not manually change this information.
```

Metadata information about Finalynx. This file is used by Fynalinx and updated by the CI/CD pipeline.
"""

__version__ = "1.4.0"

__author__ = "Pierre Laclau (MadeInPierre)"

__copyright__ = """
Copyright (c) 2023, MadeInPierre
Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee or royalty is hereby
granted, provided that the above copyright notice appear in all copies
and that both that copyright notice and this permission notice appear
in supporting documentation or portions thereof, including
modifications, that you make.
"""
